#
# spec file for package intel-media-driver
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver	7

Name:           intel-media-driver
Version:        24.4.0
Release:        1.1
Summary:        Intel Media Driver for VAAPI
License:        BSD-3-Clause AND MIT
Group:          System/Libraries
URL:            https://github.com/intel/media-driver
Source0:        %{url}/archive/refs/tags/intel-media-%{version}.tar.gz
Source1:        generate-supplements.sh
Source2:        supplements.inc
Source3:        baselibs.conf
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.5
BuildRequires:  gmmlib-devel >= 22.3.18
BuildRequires:  pkgconfig
#Note this is NOT libva library version!
BuildRequires:  pkgconfig(libva) >= 1.20.0
BuildRequires:  pkgconfig(pciaccess)
ExclusiveArch:  x86_64 i586
%include %{S:2}

%description
The Intel Media Driver for VAAPI is a new VA-API (Video Acceleration API)
user mode driver supporting hardware accelerated decoding, encoding, and
video post processing for GEN based graphics hardware.

%package -n libigfxcmrt%{so_ver}
Summary:        Intel Graphics C for Media Runtime Library
License:        MIT
Group:          System/Libraries

%description -n libigfxcmrt%{so_ver}
cmrtlib is a runtime library for Intel GPU render engine.

%package -n libigfxcmrt-devel
Summary:        Development files for Intel Graphics C for Media Runtime Library
License:        MIT
Group:          Development/Libraries/C and C++
Requires:       libigfxcmrt%{so_ver} = %{version}

%description -n libigfxcmrt-devel
cmrtlib is a runtime library for Intel GPU render engine.

This package contains the development headers for the library found in
libigfxcmrt%{so_ver}.

%prep
%setup -q -c -a 0
mv media-driver-* media-driver
chmod -x media-driver/*.md
%define __sourcedir media-driver
#sed -i -e 's,-Werror,,' media-driver/cmrtlib/linux/CMakeLists.txt

%ifarch i586
sed -i -e 's/-m${ARCH}/-m32/' -e 's/${ARCH}/"32"/' media-driver/media_driver/cmake/linux/media_compile_flags_linux.cmake
%endif

%build
srcroot=`pwd`

%ifarch i586
export CFLAGS="%optflags -D_FILE_OFFSET_BITS=64" \
       CXXFLAGS="%optflags -D_FILE_OFFSET_BITS=64"
%endif

%cmake \
    -DBUILD_SHARED_LIBS:BOOL=OFF -DMEDIA_BUILD_FATAL_WARNINGS:BOOL=OFF
%cmake_build

%install
%cmake_install

%files
%doc media-driver/README.md
%license media-driver/LICENSE.md
%{_libdir}/dri

%files -n libigfxcmrt%{so_ver}
%{_libdir}/libigfxcmrt.so.%{so_ver}
%{_libdir}/libigfxcmrt.so.%{so_ver}.*

%files -n libigfxcmrt-devel
%doc media-driver/cmrtlib/README.md
%{_includedir}/igfxcmrt
%{_libdir}/libigfxcmrt.so
%{_libdir}/pkgconfig/igfxcmrt.pc

%changelog
* Fri Oct 18 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 24.4.0:
  * [VP] Align L0 FC Common Kernel Source Code to Driver Bin Version and Fix Clamp Issue
  * [VP] VP L0 FC Procamp Enabling
  * [VP] Fix L0 FC 420PL3 ReadKernel Thread Height
  * [Encode] Remove per frame SeqParams and only update for new ones
  * [VP] Enable Vebox physical engine id report
  * [Encode] Change new encode mode from 64 to 41
  * [VP] fix 420/444 kernel multilayer issue
  * [Encode] Replace legacy functions in media_softlet for encode
  * [VP] BT2020 ColorFill L0 FC Enable
  * [VP] remove item in tems packet when color fill and no support reuse feature
  * [VP] fix coverity issue unchecked return value
  * [VP] Change L0 FC Perg Tag
  * [VP] Fix L0 FC Intermediate Surface Rect not Align
  * [Encode] Add new perf tags
  * [Media Common] [VP] Fix build error when mtl is excluded
  * [VP] FC 420 PL3 READ KERNEL READ KERNEL
  * [Encode] remove unused header
  * [Decode] Fix ref only HLK cases failure
  * [Decode] Update Cmd parser tool for decode ringinfo dump
* Tue Sep 24 2024 Dirk Müller <dmueller@suse.com>
- update to 24.3.4:
  * Disable Xe2_Hpm VD-SFC
  * Fix AV1 Vdenc TU7 GPU Hang Issue
  * Fix HEVC long scalability hang issue
  * Fix Coverity issue about 444 read kernel integrate code
  * Avoid duplicate pointer in packet pipe recycle pool
  * [Media Common] [VP][MOS] fix double free issue
* Thu Sep 12 2024 Stefan Dirsch <sndirsch@suse.com>
- update to intel-media-24.3.3 - changes since 24.1.5 (jira#PED-10348)
  * Add Lunar Lake platform support
  * bugfixes
- updated supplements
* Mon Jun 17 2024 Dirk Müller <dmueller@suse.com>
- update to intel-media-24.1.5:
  [#]## MTL/ARL-S New Changes
  * Upstream ARL-H platform
  * Fixed AVC decoding 4K VD/SFC hang issue
  * Fixed AVC interlace decoding corruption issue
  * Fixed corruption and hang when changing AV1 encoding
    segmentation map at RAB frames
  * Fixed 4K video wall test corruption that missing CSC on
    sublayer
  * Improved media perf by optimizing memory alignment if VT-D
    enabled
  [#]## Legacy platform Fixes and Improvement
  * Fixed HEVC decoding hang issue for non-intra frame without
    reference frame
  * Fixed VC1 decoding crash issue with invalid number of slice
  * Fixed vaGetimage fails related to align check
- updated supplements
* Sat Feb  3 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 24.1.3
  * bugfix release for 24.1
- updated hardware Supplmeents
* Mon Dec 11 2023 Dirk Müller <dmueller@suse.com>
- update to 23.4.3:
  * Fix many Coverity code issues
  * fix hdr cpu timeing long latency issue
  * Add BGRP format support
  * Reshape oversized buffer to texture on Small bar environment
  * fix RGB565 output width issue
  * XRGB force to do swizzle for AVC/HEVC
  * Fix cm rt leak
  * [Encode] fix slc header size issue
  * [CM] Fix coverity CM resource leak issue
* Mon Dec  4 2023 Stefan Dirsch <sndirsch@suse.com>
- This includes latest version of one of the components needed for
  Video (processing) hardware support on Intel GPUs (bsc#1217770)
* Sat Nov 18 2023 Dirk Müller <dmueller@suse.com>
- update to intel-media-23.3.5:
  * Upstream ARL-S
  * Enabled AV1 Encode ICQ feature for ACM+
  * Deprecated VAEntrypointEncSliceLP
  * Enabled PAT index setting when creating bo
  * Optimized media reset threashold through resolution
  * Fixed MTL VP9 Encode visual corruption issue for non-8 pixel
    aligned resolution
  * Fixed AVC Decode non-existing frame issue
  * Fixed MTL XRGB/ARGB tiling create/report mismatch issue
  * Fixed AV1 Encode max reference frame num caps report issue
    for ACM onwards
  * Fixed AV1 Encode multi-tiles R2R bitstream mismatch issue on
    ACM
  * Fixed VP9 header packer issue for segmentation
  * Fixed FC Corruption when Blending without Colorfill
  * Fixed a segfault for compressed surface non-32 aligned width
* Wed Sep 13 2023 Dirk Müller <dmueller@suse.com>
- update to intel-media-23.2.4:
  * Fixed AV1e obu size bits and max tile number caps report.
  * Enhanced BT2020 YUV/RGB range conversion(YUV limited to full,
    RGB full to limited).
  * Enabled PAT index for cache setting.
  * Enable GuC submission on RPL-S.
  * Supported DDI query for engine reset info for ACM+.
  * Fixed HEVC virtual tile scalability hang issue on TGL+.
  * Fixed AV1 TX_MODE_SELECT caps for bitstream corruption for
    ACM.
  * Fixed HEVC ICQ caps report for ACM.
  * Enabled HEVC VDEnc 422 encoding for ATS-M.
  * Power optimization for VP9 unaligned surface padding on TGL.
  * Fixed AVC memory management control operation w/
    adaptive_ref_pic_marking_mode_flag update for ACM+.
  * Improved HDR tone mapping performance for the case the input
    image height is not 8 aligned.
  * Fixed RGBP vaGetImage and vaPutImage.
* Tue Jun 27 2023 Dirk Müller <dmueller@suse.com>
- update to 12.1.6:
  * Official quarterly release including some enhancements and
    key fixes.
  * Enhanced AVC/HEVC/AV1 decode robustness for error case
    handling.
  * Enabled AV1 encoding error-resilient mode.
  * Fixed VP9 encoding segment fault issue with unaligned
    resolution.
  * Fixed a random crash issue for OCA log resource in multi VPP
    case.
* Fri Mar 10 2023 Stefan Dirsch <sndirsch@suse.com>
- no longer set LIBVA_DRIVER_NAME=iHD; it's no longer needed;
  implemented in libva meanwhile (boo#1209134)
* Thu Mar  9 2023 Dirk Müller <dmueller@suse.com>
- update to 23.1.3:
  * fix memleak issue on VPL AV1
  * Enhance decode robustness of slice parameters
  * VP9 fixes
  * Fix aVC performance tags (encode)
  * Fix typo in AV1 surface number (decode)
* Mon Feb 27 2023 Stefan Dirsch <sndirsch@suse.com>
- updated Supplements
* Mon Feb 27 2023 Dirk Müller <dmueller@suse.com>
- updaet to 23.1.2:
  * Fix Decode Encryption Types Missing in APO
  * Fallback to doubleBufferCopy when lock external resource failed
  * Enhance robustness of Decode SubPacket Manager
  * FP16 Enable on APOes
  * Refine mos gpu hang interface to use correct ctx id
  * Move rowstore cache regkey report to new location
  * optimize vebox resource
  * Fix Output out of scaling when using SR with Rotation
* Mon Feb 13 2023 Stefan Dirsch <sndirsch@suse.com>
- updated Supplements
* Mon Feb 13 2023 Michał Szczepaniak <m.szczepaniak.000@gmail.com>
- update to 23.1.1:
  * Add VA HEVC block sizes and features caps
  * Remove VP dependency for codec softlet lib on win/Linux
* Fri Jan  6 2023 Dirk Müller <dmueller@suse.com>
- update to 22.6.6:
  * Revert "vaGetImage optimization on D-card."
* Tue Jan  3 2023 Stefan Dirsch <sndirsch@suse.com>
- updated Supplements
* Tue Jan  3 2023 Dirk Müller <dmueller@suse.com>
- update to intel-media-22.5.4:
  * Official quarterly release including some enhancements and key fixes.
  * Alchemist(DG2)/ATS-M New Features and Enhancement
  * Enhanced HEVC & AVC decode error handling robustness.
  * Fixed VP9 dynamic resolution change decode random corruption issue.
  * Enabled Memory Decompression for ADLS and ADLN.
  * Fixed MPEG2 decode crash issue.
  * Fixed AV1 decode film grain hang issue.
  * Fixed color fill corruption issue.
  * Fixed first VPP operation color artifacts.
  * Enhanced I420 and UYVY format support in creating surface and derive
    image.
  * Fixed aux table l2 page fault
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 22.6.4:
  * Alchemist(DG2)/ATS-M New Features and Enhancement
  * Enhanced HEVC & AVC decode error handling robustness.
  * Fixed VP9 dynamic resolution change decode random corruption issue.
  * Enabled Memory Decompression for ADLS and ADLN.
  * Fixed MPEG2 decode crash issue.
  * Fixed AV1 decode film grain hang issue.
  * Fixed color fill corruption issue.
  * Fixed first VPP operation color artifacts.
  * Enhanced I420 and UYVY format support in creating surface and derive
    image.
  * Fixed aux table l2 page fault
* Mon Nov  7 2022 Stefan Dirsch <sndirsch@suse.com>
- needed for jira#PED-1174 (Video decoding/encoding support
  (VA-API, ...) for Intel GPUs is outside of Mesa)
* Wed Nov  2 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.6.1
  * Revert "[Decode] Legacy MI interface removal"
- specfile cleanup
- updated Supplements
* Sun Oct 30 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 2.6.0:
  * Revert "[Decode] Virtual Node Assign Policy Optimization"
- Code changes from version 2.5.4:
  * Enabled Memory Decompression for ADLS and ADLN.
  * Fixed MPEG2 decode crash issue.
  * Fixed AV1 decode film grain hang issue.
  * Fixed color fill corruption issue.
  * Fixed first VPP operation color artifacts.
  * Enhanced I420 and UYVY format support in creating surface and derive image.
  * Fixed aux table l2 page fault
- Remove u_libva-2.16.0.patch
* Sat Oct  1 2022 Stefan Dirsch <sndirsch@suse.com>
- adding _constraints in the hope to reserve enough disk space;
  trying with 7GB for now ...
* Fri Sep 30 2022 Stefan Dirsch <sndirsch@suse.com>
- u_libva-2.16.0.patch
  * fixes build against libva 2.16.0
  * culprit: https://github.com/intel/libva/commit/8682f9e30f2fabf2ccc6f7609db035ed1af44703
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- No code changes
- Update to version 22.4.4 was part of Intel oneVPL GPU Runtime
  2022Q2 Release 22.4.4
* Fri Jul  8 2022 Stefan Dirsch <sndirsch@suse.com>
- updated supplements.inc
* Wed Jul  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 22.4.4:
  * Enabled HDR10 and HVS support
  * Added RPL-P platform enabling
  * Added HDR10 capability report
* Fri May 27 2022 Stefan Dirsch <sndirsch@suse.com>
- disabling Werror from build no longer needed; therefore commented
  out this sed line for now ...
* Thu May 26 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 22.4.2:
  * [Encode] AVC RC mode - Implement abs QP map (MBQP) and CQP QP
  - Enable abs QP map mode caps
  - Implement programming for abs QP map mode
- removed no longer needed Werror-initialize-in-right-order.patch
* Wed Jan 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 22.1.1:
  * New Features and Enhancement:
  - Enabled Alchemist/ATS-M platform decoding and video
    processing features
  - Added ADL-N platform support
  - Enhanced AV1 decoding robustness for error clips handling
  - Added vaCopy caps reporting
  - Enabled GPU copy for small resolution in vaMap/unMap
  - Optimized GetImage perf for NV12 format
  - Added HEVC sub-features caps reporting
  - Improved compatibility by disabling compression when creating
    surface
  - Improved debuggability by enabling OCA support
  * Bugs fixed:
  - Fixed multiple layer composition corruption issue
  - Fixed OCA stability issue in multi-thread scenario
  - Fixed render copy mem leak
* Mon Nov 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 21.3.5:
  * Enabled vaCopy by GPU HW
  * Added 0YUV decode output format support
* Thu Oct 28 2021 Stefan Dirsch <sndirsch@suse.com>
- mention baselibs.conf as source in specfile
* Mon Oct 25 2021 Duarte Pousa <pousaduarte@gmail.com>
- Fix 32bit build (dependency for Steam in-home streaming hardware decode)
* Mon Oct  4 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed JIRA number in a previous changelog
* Wed Sep 29 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to 21.3.4
  * Fix regression:libva conformance failures since github issue#1229
* Mon Sep 27 2021 Stefan Dirsch <sndirsch@suse.com>
- covers jira#SLE/SLE-19361
* Wed Sep 15 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 21.3.3:
  * Supported platforms:
    BDW/SKL/APL(BXT)/KBL/CFL/WHL/CML/ICL/EHL/JSL/TGL/RKL/DG1/SG1/ADL-S/ADL-P
  * Extensive new features and enhancements, see README.md
- Move generated supplements list to supplements.inc
* Sat Oct 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.3.0:
  * Enabled AV1 4:2:0 8bit and 10bit decoding for both driver and MSDK, up to 8K video decoding and 16K still picture decoding.
  * Added Y212 and Y412 color format support for 12 bit decoding.
  * Added several RePAK related changes for VP9 performance improvements including Pak-only RePAK and adaptive-RePAK
  * Reconstructed Surface Variant formats configuration is now handled by the media-driver
  * Added HuC Error Status Report improvements for VP9 VDEnc encoding
  * Added scaling interpolation method(nearest, bilinear, advanced)
  * Added resource usage type to specify cache policy usage
  * Enabled SFC bilinear scaling.
- Disable Werror from build, which avoids having to create build fixes
  patches for every release
- remove u_20.1.1-build-fixes.patch, u_20.2.0-build-fixes.patch (obsolete)
* Mon Aug 31 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 20.2.0
  * Official quarterly release including some enhancements and key
    fixes. (needed for jira#SLE/SLE-12712)
- u_20.2.0-build-fixes.patch
  * fixed more -Werror build errors
- updated Supplements lines in specfile
* Fri Aug 28 2020 Stefan Dirsch <sndirsch@suse.com>
- moved profiles for setting env variable LIBVA_DRIVER_NAME to
  /usr/etc/profiles.d on TW (boo#1173006)
* Tue Apr 14 2020 Stefan Dirsch <sndirsch@suse.com>
- u_20.1.1-build-fixes.patch
  * fixed remaining -Werror build errors
* Fri Apr 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 20.1.1:
  * Enabled HEVC SCC Decoding.
  * VP SFC driver refactor for modularity/structure improvement.
  * Enhanced media buffer and 2D surface copy to improve
    robustness.
  * Enhanced Tile mode(Tile64, TileX, Tile4) support.
  * MOS driver refactor for modularity/robustness enhancement.
  * HEVC VDEnc Encoding
  - Added AYUV/ARGB10/Y410 format support for increased MV
    predictor range of TU1.
  - Enabled DirtyROI for better performance of static region.
  * VP9 VDEnc Encoding: Enabled scalability for better performance
    in 5k+ and range-extension real-time encoding.
  * Various bugfixes.
- For changes from previous releases, please see the included
  README.md
- Drop patches fixed upstream:
  * Werror-implicit-function-not-valid-for-C++.patch
  * U_Encode-Add-some-missing-device-IDs-for-CML-and-ICL.patch
- Rebase Werror-initialize-in-right-order.patch
* Tue Feb 25 2020 Stefan Dirsch <sndirsch@suse.com>
- generate-supplements.sh/specfile: fixed supplements lines
  (boo#1164851)
* Thu Jan 16 2020 Stefan Dirsch <sndirsch@suse.com>
- U_Encode-Add-some-missing-device-IDs-for-CML-and-ICL.patch
  * add support for support AML-Y (bsc#1160967)
* Thu Nov  7 2019 Stefan Dirsch <sndirsch@suse.com>
- This release fullfills requirements for jsc#SLE-8838
* Mon Sep  2 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 19.2.1
  * Fixed known GPU hang issue when encoding 444 8/10bit in ICL
    issue#677
  * Fixed several compile warnings.
- Werror-implicit-function-not-valid-for-C++.patch,
  Werror-initialize-in-right-order.patch
  * needed as buildfixes
* Sat Jul  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 19.2.0:
  * Release pVEInterf to fix the mem leak issue.
  * Fix memory leak during 3D surface allocation.
  * Move the lock earlier to make surface heap status aligned when
    surface is destroyd.
  * [VP] UMD_OCA Implement:
  - Add UMD_OCA support in mos.
  - Add UMD_OCA support for VP RCS case (No CM based) and
    Vebox/SFC case.
  - It is disabled by default.
  * [VP] Remove dupliatcated defines on composition.
  * Remove duplicated defines and revert part codes.
  * Full support of Gen9 CML kernel integration.
  * Stay the same compile option as Gen9.
  * Readme: update feature list for default and open source build
  * [Encode]:
  - Fix segment fault issue in Jpeg encode cases on Linux.
  - Fix Dynamic Scaling Media Reset Issue.
- Update modalias supplements.
* Mon Apr  1 2019 tiwai@suse.de
- Updated to version 18.4.1:
  * Supported Platforms:
  - BDW/SKL/APL(BXT)/KBL/CFL/WHL/CNL/ICL
  * Improvements:
  - WHL: Added WHL support and enabled its VP8 encoding.
  - ICL: Added ICL open source compute shaders for video processing.
    Enabled ICL HDR10 Tone Mapping using close source compute shaders.
  - DRM uAPI relative code is refactored to better comply to i915
    Open Source Userspace Requirement.
  - Added X11 build option detection.
  - Enabled software swizzling support to improve surface reading
    performance of vaGetImage.
  - Added ARGB,Y410 image format support.
  - Added versioning information to CMRT library.
  - BRC enhancement:
    AVC hardware encoding: added QVBR support.
    AVC shader encoding: added AVBR and max frame size BRC support.
    VP8 encoding: corrected fps calculation error.
  * Fixed issues:
  - GStreamer/gstreamer-vaapi integration:
    Fixed the issue about KBL HEVC P010_10LE encoding kernel state
    initialization failure for CODECHAL_HEVC_MBENC_PENC.
    Fixed the issue about aspect ratio being unable to retain in
    video processsing PutSurface for vaapisink display.
  - Corrected RT format reporting for HEVC main10 profile.
  - Corrected caps reporting of max width/height for VP9 decoding
    from 2k (2048x2048) to 8k (8192x8192).
- Add sub-packages libigfxcmrt7 and libigfxcmrt-devel
- Updated supplements accordingly
* Tue Nov 13 2018 sndirsch@suse.com
- added hardware supplements in order to install the package on
  appropriate hardware (Broadwell, Skylake, Broxton/Apollo Lake,
  Kaby Lake, Coffee Lake, Cannonlake, Ice Lake at this time)
- added script to generate the above information easily
* Wed Nov  7 2018 tiwai@suse.de
- Updated to version 18.3.0:
  * Adding ICL support
  * Adding dynamic loading support of Gmmlib
  * Better support to ffmpeg and gstreamer:
    + AVC low power encoding
    + MPEG2 encoding
    + VP8 decoding
    + VC1 decoding
    + JPEG encoding and decoding
  * Adding Dockerfile and docker images
- Use shared lib of gmmlib; added buildreq accordingly
* Tue Jul 10 2018 tiwai@suse.de
- initial package: media-driver Q2'18 release
